diff --git a/Trigger/TrigAlgorithms/TrigT2BeamSpot/python/T2VertexBeamSpotMonitoring.py b/Trigger/TrigAlgorithms/TrigT2BeamSpot/python/T2VertexBeamSpotMonitoring.py
index 052005c2bd4998e579e119d32c4626b5f3cfb622..38f93eb895c02f760e6ce02fe15ef42fca5e99a7 100644
--- a/Trigger/TrigAlgorithms/TrigT2BeamSpot/python/T2VertexBeamSpotMonitoring.py
+++ b/Trigger/TrigAlgorithms/TrigT2BeamSpot/python/T2VertexBeamSpotMonitoring.py
@@ -35,13 +35,13 @@ class T2VertexBeamSpotOnlineMonitoring(TrigGenericMonitoringToolConfig):
             #---------------------------------------
 
             # Number of tracks per event
             # Total number of bins: 400
             self.Histograms += [ defineHistogram('TotalTracks', type='TH1F',
                                                  title="TotalTracks; N tracks per event; Number of events",
-                                                 xbins=200, xmin=0.0, xmax=200.0) ]
+                                                 xbins=300, xmin=0.0, xmax=600.0) ]
             self.Histograms += [ defineHistogram('TotalTracksPass', type='TH1F',
                                                  title="TotalTracksPass;  N accepted tracks per event; Number of events",
-                                                 xbins=200, xmin=0.0, xmax=200.0) ]
+                                                 xbins=300, xmin=0.0, xmax=500.0) ]
 
             # Track Z position
             # Total number of Bins: 200
@@ -35,13 +35,13 @@ class T2VertexBeamSpotOnlineMonitoring(TrigGenericMonitoringToolConfig):
 
             # Number of tracks per event
-            # Total number of bins: 400
+            # Total number of bins: 600
             self.Histograms += [ defineHistogram('TotalTracks', type='TH1F',
                                                  title="TotalTracks; N tracks per event; Number of events",